@@ -4,7 +4,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2011	PgPool Global Development Group
+ * Copyright (c) 2003-2016	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -25,7 +25,8 @@
 
 #ifndef LIBPCP_EXT_H
 #define LIBPCP_EXT_H
-
+#include <signal.h>
+#include <stdio.h>
 /*
  * startup packet definitions (v2) stolen from PostgreSQL
  */
@@ -62,7 +63,12 @@ typedef struct {
 } BackendInfo;
 
 typedef struct {
-	int num_backends;		/* number of used PostgreSQL backends */
+	sig_atomic_t num_backends;		/* Number of used PostgreSQL backends.
+									 * This needs to be a sig_atomic_t type
+									 * since it is replaced by a local
+									 * variable while reloading pgpool.conf.
+									 */
+
 	BackendInfo backend_info[MAX_NUM_BACKENDS];
 } BackendDesc;
 /*
@@ -163,7 +169,7 @@ typedef struct {
 #define POOLCONFIG_MAXIDLEN 4
 #define POOLCONFIG_MAXNAMELEN 64
 #define POOLCONFIG_MAXVALLEN 512
-#define POOLCONFIG_MAXDESCLEN 64
+#define POOLCONFIG_MAXDESCLEN 80
 #define POOLCONFIG_MAXIDENTLEN 63
 #define POOLCONFIG_MAXPORTLEN 6
 #define POOLCONFIG_MAXSTATLEN 2
